Crate k8s_insider_core

Crate k8s_insider_core 

Modules

detectors
helpers
ip
kubernetes
resources
tunnel_info
wireguard

Constants

CONTROLLER_CLUSTERROLE_NAME
NETWORK_MANAGER_CLUSTERROLE_NAME
RESOURCE_GROUP
ROUTER_CLUSTERROLE_NAME

Traits

AsPrimitive
A generic interface for casting between machine scalars with the as operator, which admits narrowing and precision loss. Implementers of this trait AsPrimitive should behave like a primitive numeric type (e.g. a newtype around another primitive), and the intended conversion must never fail.
FromPrimitive
A generic trait for converting a number to a value.
Unsigned
A trait for values which cannot be negative