Modules
Constants
Traits
- AsPrimitive
- A generic interface for casting between machine scalars with the
asoperator, which admits narrowing and precision loss. Implementers of this traitAsPrimitiveshould behave like a primitive numeric type (e.g. a newtype around another primitive), and the intended conversion must never fail. - From
Primitive - A generic trait for converting a number to a value.
- Unsigned
- A trait for values which cannot be negative